==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_StockData.pm <==
package WebGUI::i18n::Spanish::Asset_StockData;
use utf8;
our $I18N = {
  '% Change' => {
    'lastUpdated' => '1253415082',
    'message' => '% Variación'
  },
  '52 Wk High' => {
    'lastUpdated' => '1253415136',
    'message' => 'Máximo 52 Sem'
  },
  '52 Wk Low' => {
    'lastUpdated' => '1253415148',
    'message' => 'Mínimo 52 Semanas'
  },
  'Change' => {
    'lastUpdated' => '1253415160',
    'message' => 'Variación'
  },
  'Close' => {
    'lastUpdated' => '1253999268',
    'message' => 'Cerrar'
  },
  'Day High' => {
    'lastUpdated' => '1253999313',
    'message' => 'Máximo del Día'
  },
  'Day Low' => {
    'lastUpdated' => '1253415184',
    'message' => 'Mínimo del Día'
  },
  'Dividend' => {
    'lastUpdated' => '1253999328',
    'message' => 'Dividendo'
  },
  'EPS' => {
    'lastUpdated' => '1253999341',
    'message' => 'G.P.A.'
  },
  'Exchange' => {
    'lastUpdated' => '1253999356',
    'message' => 'Negociada en'
  },
  'Last Trade' => {
    'lastUpdated' => '1253999362',
    'message' => 'Ultima Operación'
  },
  'Last Update' => {
    'lastUpdated' => '1253999369',
    'message' => 'Ultimo Cambio'
  },
  'Market Cap' => {
    'lastUpdated' => '1253999378',
    'message' => 'Capitalización'
  },
  'Open' => {
    'lastUpdated' => '1253999393',
    'message' => 'Apertura'
  },
  'Prev Close' => {
    'lastUpdated' => '1253999403',
    'message' => 'Cierre Previo'
  },
  'Stock Watch' => {
    'lastUpdated' => '1253999449',
    'message' => 'Valores a Seguir'
  },
  'Volume' => {
    'lastUpdated' => '1253415290',
    'message' => 'Volumen'
  },
  'Yield' => {
    'lastUpdated' => '1253999503',
    'message' => 'Utilidad'
  },
  'add_button_label' => {
    'lastUpdated' => '1253999510',
    'message' => 'Agregar &gt;&gt;'
  },
  'assetName' => {
    'lastUpdated' => '1253415330',
    'message' => 'Acciones y Valores'
  },
  'defaultStocks' => {
    'lastUpdated' => '1253999521',
    'message' => 'La lista por defecto de las Acciones Valores si el usuario no selecciona ninguna.'
  },
  'default_stock_description' => {
    'lastUpdated' => '1253415383',
    'message' => 'Ingrese las Acciones Valores que desea mostrar a los visitantes y usuarios que no han especificado una lista personal preferida. Ingrese un símbolo por línea.'
  },
  'default_stock_label' => {
    'lastUpdated' => '1253415395',
    'message' => 'Acciones Valores por Defecto'
  },
  'default_stock_label_description' => {
    'lastUpdated' => '1253415409',
    'message' => 'Ingrese la lista de Acciones Valores por defecto, uno por línea.'
  },
  'delayed 20 minutes' => {
    'lastUpdated' => '1253415418',
    'message' => 'retraso de 20 minutos'
  },
  'delete_confirm' => {
    'lastUpdated' => '1253415439',
    'message' => '¿Está seguro que quiere eliminar %s de la Lista de Acciones Valores?'
  },
  'displayTemplateId' => {
    'lastUpdated' => '1253415462',
    'message' => 'El ID de la Plantilla empleada para desplegar los detalles de las Acciones Valores a los usuarios.'
  },
  'display_template_label' => {
    'lastUpdated' => '1253415473',
    'message' => 'Plantilla para Mostrar Acciones Valores'
  },
  'display_template_label_description' => {
    'lastUpdated' => '1253415494',
    'message' => 'Seleccione la Plantilla utilizada para desplegar las Acciones Valores individuales.'
  },
  'editUrl' => {
    'lastUpdated' => '1253415508',
    'message' => 'El URL a la página donde el usuario puede especificar sus Acciones Valores.'
  },
  'edit_title' => {
    'lastUpdated' => '1253415517',
    'message' => 'Editar lista de Acciones Valores'
  },
  'extrasFolder' => {
    'lastUpdated' => '1253415545',
    'message' => 'El URL al directorio de extras que contiene archivos CSS e imágenes empleadas por la aplicación de Lista de Acciones Valores.'
  },
  'failover' => {
    'lastUpdated' => '1253999678',
    'message' => 'Un condicional que indica si la información de Acciones Valores debe consultarse desde múltiples fuentes o solamente desde la fuente principal.'
  },
  'failover_description' => {
    'lastUpdated' => '1253999632',
    'message' => 'Esta opción indica que se buscará sobre todas las fuentes de información sobre Acciones Valores, a partir de la fuente principal. Si se seleccionar \'no\', solamente se buscará en la fuente de información principal, teniendo como resultado menos información disponible para los usuarios, pero mejor desempeño en la búsqueda de información.'
  },
  'failover_label' => {
    'lastUpdated' => '1253999645',
    'message' => 'Múltiples Fuentes'
  },
  'failover_label_description' => {
    'lastUpdated' => '1253999770',
    'message' => 'Indicar \'si\' tiene el efecto de incorporar información de Acciones Valores tomadas desde todas las fuentes a través de Internet. Indicar \'no\' tiene el efecto de restringir la búsqueda a la fuente princiapl. Esto mejora notablemente el desempeño de las búsquedas, pero limita los títulos valores disponibles a una sola fuente de información.'
  },
  'finish_button_label' => {
    'lastUpdated' => '1253999796',
    'message' => 'Terminar'
  },
  'help_stock_list_display_template' => {
    'lastUpdated' => '1253999849',
    'message' => 'Variables de Plantilla para Mostrar Lista de Acciones Valores'
  },
  'help_stock_list_template' => {
    'lastUpdated' => '1253999829',
    'message' => 'Variables de Plantilla para Listado de Acciones Valores'
  },
  'isVisitor' => {
    'lastUpdated' => '1253999868',
    'message' => 'Un condicional que indica si el usuario es un visitante o no.'
  },
  'lastUpdate.default' => {
    'lastUpdated' => '1253999926',
    'message' => 'Fecha y hora en la cual el precio de las Acciones Valores fue modificado por última vez, en el formato por omisión de fecha y hora.'
  },
  'lastUpdate.intl' => {
    'lastUpdated' => '1253999940',
    'message' => 'Fecha y hora en la cual el precio de las Acciones Valores fue
modificado por última vez, en el formato internacional de fecha y hora.'
  },
  'lastUpdate.us' => {
    'lastUpdated' => '1253999968',
    'message' => 'Fecha y hora en la cual el precio de las Acciones Valores fue
modificado por última vez, en el formato estadounidense de fecha y hora.'
  },
  'no_symbol' => {
    'lastUpdated' => '1253999993',
    'message' => 'El símbolo %s no pudo encontrarse en la lista de fuentes de información sobre Acciones Valores.'
  },
  'no_symbol_error' => {
    'lastUpdated' => '1254000017',
    'message' => 'No indicó ningún símbolo para agregar a su lista.'
  },
  'source' => {
    'lastUpdated' => '1254000038',
    'message' => 'La fuente de Internet a emplear para obtener información sobre Acciones Valores.'
  },
  'stock data asset template variables title' => {
    'lastUpdated' => '1254000056',
    'message' => 'Variables de Plantilla para Datos de Acciones Valores'
  },
  'stock.display.url' => {
    'lastUpdated' => '1254000094',
    'message' => 'El URL a la página que presenta los detalles para las Acciones Valores individuales. El símbolo específico para una Acción Valor debe agregarse al final de este URL.'
  },
  'stock_source' => {
    'lastUpdated' => '1254000104',
    'message' => 'Fuente Principal'
  },
  'stock_source_description' => {
    'lastUpdated' => '1254000190',
    'message' => 'Seleccione la Fuente Principal desde la cual obtener información sobre Acciones Valores. Esta es la primera ubicación en Internet sobre la cual realizar búsquedas. Indicar la fuente que contenga la mayoría de los símbolos de interés para sus usuarios hará que el desempeño de las búsquedas para el Listado de Acciones Valores mejore.'
  },
  'stocks.ask' => {
    'lastUpdated' => '1254000206',
    'message' => 'Venta'
  },
  'stocks.avg_vol' => {
    'lastUpdated' => '1254000219',
    'message' => 'Volumen Promedio Diario'
  },
  'stocks.bid' => {
    'lastUpdated' => '1254000238',
    'message' => 'Oferta'
  },
  'stocks.cap' => {
    'lastUpdated' => '1254000247',
    'message' => 'Capitalización'
  },
  'stocks.close' => {
    'lastUpdated' => '1254000256',
    'message' => 'Cierre Previo'
  },
  'stocks.date' => {
    'lastUpdated' => '1254000286',
    'message' => 'Ultima Transacción'
  },
  'stocks.day_range' => {
    'lastUpdated' => '1254000382',
    'message' => 'Rango en el día'
  },
  'stocks.div' => {
    'lastUpdated' => '1254000392',
    'message' => 'Dividendo por Acción'
  },
  'stocks.div_date' => {
    'lastUpdated' => '1254000402',
    'message' => 'Pago de Dividendos'
  },
  'stocks.div_yield' => {
    'lastUpdated' => '1254000415',
    'message' => 'Utilidad'
  },
  'stocks.eps' => {
    'lastUpdated' => '1254000424',
    'message' => 'G.P.A.'
  },
  'stocks.errormsg' => {
    'lastUpdated' => '1254000448',
    'message' => 'Si la variable <strong>success</strong> es falsa, esta variable puede contener la razón de la falla.'
  },
  'stocks.ex_div' => {
    'lastUpdated' => '1254000533',
    'message' => 'Dividendos a partir de'
  },
  'stocks.exchange' => {
    'lastUpdated' => '1254000552',
    'message' => 'El mercado desde el cual se obtuvo la información.'
  },
  'stocks.high' => {
    'lastUpdated' => '1254000574',
    'message' => 'Valor máximo de negociación para el día de hoy.'
  },
  'stocks.last' => {
    'lastUpdated' => '1254000612',
    'message' => 'Ultimo Precio'
  },
  'stocks.loop' => {
    'lastUpdated' => '1254000637',
    'message' => 'Un ciclo que itera sobre todas las Acciones Valores, estándar y personalizadas.'
  },
  'stocks.low' => {
    'lastUpdated' => '1254000649',
    'message' => 'Precio mínimo de negociación para el día.'
  },
  'stocks.method' => {
    'lastUpdated' => '1254000685',
    'message' => 'El módulo que obtuvo la información.'
  },
  'stocks.name' => {
    'lastUpdated' => '1254000697',
    'message' => 'Nombre de la Compañía o Fondo Mutual'
  },
  'stocks.nav' => {
    'lastUpdated' => '1254000717',
    'message' => 'Valor Neto Activo'
  },
  'stocks.net' => {
    'lastUpdated' => '1254000725',
    'message' => 'Cambio Neto'
  },
  'stocks.net.icon' => {
    'lastUpdated' => '1254000743',
    'message' => 'El ícono asociado con el cambio neto (sube, baja, mantiene).'
  },
  'stocks.net.isDown' => {
    'lastUpdated' => '1254000764',
    'message' => 'Indica si el cambio neto es negativo.'
  },
  'stocks.net.isUp' => {
    'lastUpdated' => '1254000774',
    'message' => 'Indica si el cambio neto es positivo.'
  },
  'stocks.net.noChange' => {
    'lastUpdated' => '1254000786',
    'message' => 'Indica que el cambio neto es cero.'
  },
  'stocks.open' => {
    'lastUpdated' => '1254000797',
    'message' => 'Apertura en'
  },
  'stocks.p_change' => {
    'lastUpdated' => '1254000814',
    'message' => 'Cambio porcentual en relación al cierre de ayer.'
  },
  'stocks.pe' => {
    'lastUpdated' => '1254000829',
    'message' => 'Relación Precio/Ganancia'
  },
  'stocks.success' => {
    'lastUpdated' => '1254000852',
    'message' => 'Un condicional que indica si la fuente de Acciones Valores retornó información o no.'
  },
  'stocks.symbol' => {
    'lastUpdated' => '1254000864',
    'message' => 'Símbolo de Acción Valor'
  },
  'stocks.time' => {
    'lastUpdated' => '1254000874',
    'message' => 'Hora de última transacción'
  },
  'stocks.volume' => {
    'lastUpdated' => '1254000884',
    'message' => 'Volumen del día'
  },
  'stocks.volume.millions' => {
    'lastUpdated' => '1254000894',
    'message' => 'Volumen del día en millones'
  },
  'stocks.year_high' => {
    'lastUpdated' => '1254000907',
    'message' => 'Máximo Anual'
  },
  'stocks.year_low' => {
    'lastUpdated' => '1254000916',
    'message' => 'Mínimo Anual'
  },
  'stocks.year_range' => {
    'lastUpdated' => '1254000924',
    'message' => 'Rango Anual'
  },
  'stocks.yield' => {
    'lastUpdated' => '1254000938',
    'message' => 'Utilidad (usualmente promedio de 30 días)'
  },
  'symbol_edit_label' => {
    'lastUpdated' => '1254000950',
    'message' => 'Agregar/Editar Símbolos de Acciones'
  },
  'symbol_exists' => {
    'lastUpdated' => '1254000966',
    'message' => 'El símbolo %s ya está en su Lista de Acciones Valores'
  },
  'symbol_header' => {
    'lastUpdated' => '1254000980',
    'message' => 'Lista de Símbolos de Acciones Valores'
  },
  'symbol_label' => {
    'lastUpdated' => '1254000991',
    'message' => 'Símbolo de Acción Valor'
  },
  'symbol_label_description' => {
    'lastUpdated' => '1254001041',
    'message' => 'Ingrese un símbolo válido para alguna Acción Valor. Si el símbolo que introduce no puede ser encontrado por el sistema, contacte al administrador del sitio. Es probable que el sitio restringa el uso de símbolos para un mercado particular.'
  },
  'templateId' => {
    'lastUpdated' => '1254001062',
    'message' => 'El ID de la Plantilla empleada para desplegar la pantalla principal del Activo.'
  },
  'template_label' => {
    'lastUpdated' => '1254001122',
    'message' => 'Plantilla para Listado de Acciones'
  },
  'template_label_description' => {
    'lastUpdated' => '1254001144',
    'message' => 'Seleccione la Plantilla a emplear para desplegar la Lista de Acciones.'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_StockData.pm <==
package WebGUI::i18n::Spanish::Asset_StockData;
use utf8;
our $I18N = {
  '% Change' => {
    'lastUpdated' => '1253415082',
    'message' => '% Variación'
  },
  '52 Wk High' => {
    'lastUpdated' => '1253415136',
    'message' => 'Máximo 52 Sem'
  },
  '52 Wk Low' => {
    'lastUpdated' => '1253415148',
    'message' => 'Mínimo 52 Semanas'
  },
  'Change' => {
    'lastUpdated' => '1253415160',
    'message' => 'Variación'
  },
  'Close' => {
    'lastUpdated' => '1253999268',
    'message' => 'Cerrar'
  },
  'Day High' => {
    'lastUpdated' => '1253999313',
    'message' => 'Máximo del Día'
  },
  'Day Low' => {
    'lastUpdated' => '1253415184',
    'message' => 'Mínimo del Día'
  },
  'Dividend' => {
    'lastUpdated' => '1253999328',
    'message' => 'Dividendo'
  },
  'EPS' => {
    'lastUpdated' => '1253999341',
    'message' => 'G.P.A.'
  },
  'Exchange' => {
    'lastUpdated' => '1253999356',
    'message' => 'Negociada en'
  },
  'Last Trade' => {
    'lastUpdated' => '1253999362',
    'message' => 'Ultima Operación'
  },
  'Last Update' => {
    'lastUpdated' => '1253999369',
    'message' => 'Ultimo Cambio'
  },
  'Market Cap' => {
    'lastUpdated' => '1253999378',
    'message' => 'Capitalización'
  },
  'Open' => {
    'lastUpdated' => '1253999393',
    'message' => 'Apertura'
  },
  'Prev Close' => {
    'lastUpdated' => '1253999403',
    'message' => 'Cierre Previo'
  },
  'Stock Watch' => {
    'lastUpdated' => '1253999449',
    'message' => 'Valores a Seguir'
  },
  'Volume' => {
    'lastUpdated' => '1253415290',
    'message' => 'Volumen'
  },
  'Yield' => {
    'lastUpdated' => '1253999503',
    'message' => 'Utilidad'
  },
  'add_button_label' => {
    'lastUpdated' => '1253999510',
    'message' => 'Agregar &gt;&gt;'
  },
  'assetName' => {
    'lastUpdated' => '1253415330',
    'message' => 'Acciones y Valores'
  },
  'cache timeout help' => {
    'lastUpdated' => '1302873407',
    'message' => '¿Cuánto tiempo almacenar en caché la información obtenida para cada símbolo?'
  },
  'defaultStocks' => {
    'lastUpdated' => '1253999521',
    'message' => 'La lista por defecto de las Acciones Valores si el usuario no selecciona ninguna.'
  },
  'default_stock_description' => {
    'lastUpdated' => '1253415383',
    'message' => 'Ingrese las Acciones Valores que desea mostrar a los visitantes y usuarios que no han especificado una lista personal preferida. Ingrese un símbolo por línea.'
  },
  'default_stock_label' => {
    'lastUpdated' => '1253415395',
    'message' => 'Acciones Valores por Defecto'
  },
  'default_stock_label_description' => {
    'lastUpdated' => '1253415409',
    'message' => 'Ingrese la lista de Acciones Valores por defecto, uno por línea.'
  },
  'delayed 20 minutes' => {
    'lastUpdated' => '1253415418',
    'message' => 'retraso de 20 minutos'
  },
  'delete_confirm' => {
    'lastUpdated' => '1253415439',
    'message' => '¿Está seguro que quiere eliminar %s de la Lista de Acciones Valores?'
  },
  'displayTemplateId' => {
    'lastUpdated' => '1253415462',
    'message' => 'El ID de la Plantilla empleada para desplegar los detalles de las Acciones Valores a los usuarios.'
  },
  'display_template_label' => {
    'lastUpdated' => '1253415473',
    'message' => 'Plantilla para Mostrar Acciones Valores'
  },
  'display_template_label_description' => {
    'lastUpdated' => '1253415494',
    'message' => 'Seleccione la Plantilla utilizada para desplegar las Acciones Valores individuales.'
  },
  'editUrl' => {
    'lastUpdated' => '1253415508',
    'message' => 'El URL a la página donde el usuario puede especificar sus Acciones Valores.'
  },
  'edit_title' => {
    'lastUpdated' => '1253415517',
    'message' => 'Editar lista de Acciones Valores'
  },
  'extrasFolder' => {
    'lastUpdated' => '1253415545',
    'message' => 'El URL al directorio de extras que contiene archivos CSS e imágenes empleadas por la aplicación de Lista de Acciones Valores.'
  },
  'failover' => {
    'lastUpdated' => '1253999678',
    'message' => 'Un condicional que indica si la información de Acciones Valores debe consultarse desde múltiples fuentes o solamente desde la fuente principal.'
  },
  'failover_description' => {
    'lastUpdated' => '1253999632',
    'message' => 'Esta opción indica que se buscará sobre todas las fuentes de información sobre Acciones Valores, a partir de la fuente principal. Si se seleccionar \'no\', solamente se buscará en la fuente de información principal, teniendo como resultado menos información disponible para los usuarios, pero mejor desempeño en la búsqueda de información.'
  },
  'failover_label' => {
    'lastUpdated' => '1253999645',
    'message' => 'Múltiples Fuentes'
  },
  'failover_label_description' => {
    'lastUpdated' => '1253999770',
    'message' => 'Indicar \'si\' tiene el efecto de incorporar información de Acciones Valores tomadas desde todas las fuentes a través de Internet. Indicar \'no\' tiene el efecto de restringir la búsqueda a la fuente princiapl. Esto mejora notablemente el desempeño de las búsquedas, pero limita los títulos valores disponibles a una sola fuente de información.'
  },
  'finish_button_label' => {
    'lastUpdated' => '1253999796',
    'message' => 'Terminar'
  },
  'help_stock_list_display_template' => {
    'lastUpdated' => '1253999849',
    'message' => 'Variables de Plantilla para Mostrar Lista de Acciones Valores'
  },
  'help_stock_list_template' => {
    'lastUpdated' => '1253999829',
    'message' => 'Variables de Plantilla para Listado de Acciones Valores'
  },
  'isVisitor' => {
    'lastUpdated' => '1253999868',
    'message' => 'Un condicional que indica si el usuario es un visitante o no.'
  },
  'lastUpdate.default' => {
    'lastUpdated' => '1253999926',
    'message' => 'Fecha y hora en la cual el precio de las Acciones Valores fue modificado por última vez, en el formato por omisión de fecha y hora.'
  },
  'lastUpdate.intl' => {
    'lastUpdated' => '1253999940',
    'message' => 'Fecha y hora en la cual el precio de las Acciones Valores fue
modificado por última vez, en el formato internacional de fecha y hora.'
  },
  'lastUpdate.us' => {
    'lastUpdated' => '1253999968',
    'message' => 'Fecha y hora en la cual el precio de las Acciones Valores fue
modificado por última vez, en el formato estadounidense de fecha y hora.'
  },
  'no_symbol' => {
    'lastUpdated' => '1253999993',
    'message' => 'El símbolo %s no pudo encontrarse en la lista de fuentes de información sobre Acciones Valores.'
  },
  'no_symbol_error' => {
    'lastUpdated' => '1254000017',
    'message' => 'No indicó ningún símbolo para agregar a su lista.'
  },
  'source' => {
    'lastUpdated' => '1254000038',
    'message' => 'La fuente de Internet a emplear para obtener información sobre Acciones Valores.'
  },
  'stock data asset template variables title' => {
    'lastUpdated' => '1254000056',
    'message' => 'Variables de Plantilla para Datos de Acciones Valores'
  },
  'stock.display.url' => {
    'lastUpdated' => '1254000094',
    'message' => 'El URL a la página que presenta los detalles para las Acciones Valores individuales. El símbolo específico para una Acción Valor debe agregarse al final de este URL.'
  },
  'stock_source' => {
    'lastUpdated' => '1254000104',
    'message' => 'Fuente Principal'
  },
  'stock_source_description' => {
    'lastUpdated' => '1254000190',
    'message' => 'Seleccione la Fuente Principal desde la cual obtener información sobre Acciones Valores. Esta es la primera ubicación en Internet sobre la cual realizar búsquedas. Indicar la fuente que contenga la mayoría de los símbolos de interés para sus usuarios hará que el desempeño de las búsquedas para el Listado de Acciones Valores mejore.'
  },
  'stocks.ask' => {
    'lastUpdated' => '1254000206',
    'message' => 'Venta'
  },
  'stocks.avg_vol' => {
    'lastUpdated' => '1254000219',
    'message' => 'Volumen Promedio Diario'
  },
  'stocks.bid' => {
    'lastUpdated' => '1254000238',
    'message' => 'Oferta'
  },
  'stocks.cap' => {
    'lastUpdated' => '1254000247',
    'message' => 'Capitalización'
  },
  'stocks.close' => {
    'lastUpdated' => '1254000256',
    'message' => 'Cierre Previo'
  },
  'stocks.date' => {
    'lastUpdated' => '1254000286',
    'message' => 'Ultima Transacción'
  },
  'stocks.day_range' => {
    'lastUpdated' => '1254000382',
    'message' => 'Rango en el día'
  },
  'stocks.div' => {
    'lastUpdated' => '1254000392',
    'message' => 'Dividendo por Acción'
  },
  'stocks.div_date' => {
    'lastUpdated' => '1254000402',
    'message' => 'Pago de Dividendos'
  },
  'stocks.div_yield' => {
    'lastUpdated' => '1254000415',
    'message' => 'Utilidad'
  },
  'stocks.eps' => {
    'lastUpdated' => '1254000424',
    'message' => 'G.P.A.'
  },
  'stocks.errormsg' => {
    'lastUpdated' => '1254000448',
    'message' => 'Si la variable <strong>success</strong> es falsa, esta variable puede contener la razón de la falla.'
  },
  'stocks.ex_div' => {
    'lastUpdated' => '1254000533',
    'message' => 'Dividendos a partir de'
  },
  'stocks.exchange' => {
    'lastUpdated' => '1254000552',
    'message' => 'El mercado desde el cual se obtuvo la información.'
  },
  'stocks.high' => {
    'lastUpdated' => '1254000574',
    'message' => 'Valor máximo de negociación para el día de hoy.'
  },
  'stocks.last' => {
    'lastUpdated' => '1254000612',
    'message' => 'Ultimo Precio'
  },
  'stocks.loop' => {
    'lastUpdated' => '1254000637',
    'message' => 'Un ciclo que itera sobre todas las Acciones Valores, estándar y personalizadas.'
  },
  'stocks.low' => {
    'lastUpdated' => '1254000649',
    'message' => 'Precio mínimo de negociación para el día.'
  },
  'stocks.method' => {
    'lastUpdated' => '1254000685',
    'message' => 'El módulo que obtuvo la información.'
  },
  'stocks.name' => {
    'lastUpdated' => '1254000697',
    'message' => 'Nombre de la Compañía o Fondo Mutual'
  },
  'stocks.nav' => {
    'lastUpdated' => '1254000717',
    'message' => 'Valor Neto Activo'
  },
  'stocks.net' => {
    'lastUpdated' => '1254000725',
    'message' => 'Cambio Neto'
  },
  'stocks.net.icon' => {
    'lastUpdated' => '1254000743',
    'message' => 'El ícono asociado con el cambio neto (sube, baja, mantiene).'
  },
  'stocks.net.isDown' => {
    'lastUpdated' => '1254000764',
    'message' => 'Indica si el cambio neto es negativo.'
  },
  'stocks.net.isUp' => {
    'lastUpdated' => '1254000774',
    'message' => 'Indica si el cambio neto es positivo.'
  },
  'stocks.net.noChange' => {
    'lastUpdated' => '1254000786',
    'message' => 'Indica que el cambio neto es cero.'
  },
  'stocks.open' => {
    'lastUpdated' => '1254000797',
    'message' => 'Apertura en'
  },
  'stocks.p_change' => {
    'lastUpdated' => '1254000814',
    'message' => 'Cambio porcentual en relación al cierre de ayer.'
  },
  'stocks.pe' => {
    'lastUpdated' => '1254000829',
    'message' => 'Relación Precio/Ganancia'
  },
  'stocks.success' => {
    'lastUpdated' => '1254000852',
    'message' => 'Un condicional que indica si la fuente de Acciones Valores retornó información o no.'
  },
  'stocks.symbol' => {
    'lastUpdated' => '1254000864',
    'message' => 'Símbolo de Acción Valor'
  },
  'stocks.time' => {
    'lastUpdated' => '1254000874',
    'message' => 'Hora de última transacción'
  },
  'stocks.volume' => {
    'lastUpdated' => '1254000884',
    'message' => 'Volumen del día'
  },
  'stocks.volume.millions' => {
    'lastUpdated' => '1254000894',
    'message' => 'Volumen del día en millones'
  },
  'stocks.year_high' => {
    'lastUpdated' => '1254000907',
    'message' => 'Máximo Anual'
  },
  'stocks.year_low' => {
    'lastUpdated' => '1254000916',
    'message' => 'Mínimo Anual'
  },
  'stocks.year_range' => {
    'lastUpdated' => '1254000924',
    'message' => 'Rango Anual'
  },
  'stocks.yield' => {
    'lastUpdated' => '1254000938',
    'message' => 'Utilidad (usualmente promedio de 30 días)'
  },
  'symbol_edit_label' => {
    'lastUpdated' => '1254000950',
    'message' => 'Agregar/Editar Símbolos de Acciones'
  },
  'symbol_exists' => {
    'lastUpdated' => '1254000966',
    'message' => 'El símbolo %s ya está en su Lista de Acciones Valores'
  },
  'symbol_header' => {
    'lastUpdated' => '1254000980',
    'message' => 'Lista de Símbolos de Acciones Valores'
  },
  'symbol_label' => {
    'lastUpdated' => '1254000991',
    'message' => 'Símbolo de Acción Valor'
  },
  'symbol_label_description' => {
    'lastUpdated' => '1254001041',
    'message' => 'Ingrese un símbolo válido para alguna Acción Valor. Si el símbolo que introduce no puede ser encontrado por el sistema, contacte al administrador del sitio. Es probable que el sitio restringa el uso de símbolos para un mercado particular.'
  },
  'templateId' => {
    'lastUpdated' => '1254001062',
    'message' => 'El ID de la Plantilla empleada para desplegar la pantalla principal del Activo.'
  },
  'template_label' => {
    'lastUpdated' => '1254001122',
    'message' => 'Plantilla para Listado de Acciones'
  },
  'template_label_description' => {
    'lastUpdated' => '1254001144',
    'message' => 'Seleccione la Plantilla a emplear para desplegar la Lista de Acciones.'
  }
}
;

1;
